@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer2::Logger::LogReport;
 use vars '$VERSION';
-$VERSION = '1.15';
+$VERSION = '1.16';
 
 # ABSTRACT: Dancer2 logger engine for Log::Report
 
@@ -66,11 +66,11 @@ around 'error' => sub {
 };
 
 
-sub log($$$)
+sub log   # no protoypes in Dancer2
 {   my ($self, $level, $msg) = @_;
 
     # the levels are nearly the same.
-    my $reason = $level_dancer2lr{$level} // uc $level;
+    my $reason = $level_dancer2lr{$level} || uc $level;
 
     report $reason => $msg;
     undef;
